import base64
import os
import tempfile
from flask import jsonify, Response
from gradio_client import Client, handle_file

class RenderController:
    def post_render(self, hf_token='', base_image=None,
                   prompt='A realistic photo of a building',
                   negative_prompt="sketch, drawing",
                   instruct_query='use everything from the image',
                   scale=0.8,
                   nfaa_negative_prompt='naked, bikini, skimpy, scanty, bare skin, lingerie, swimsuit, exposed, see-through') -> Response:

        if not base_image:
            return jsonify({"error": "Aucune image envoyée"}), 400

        if base_image.filename == '':
            return jsonify({"error": "Nom de fichier vide"}), 400

        # Définir un chemin temporaire compatible avec tous les OS
        temp_dir = tempfile.gettempdir()
        temp_path = os.path.join(temp_dir, base_image.filename)

        # Sauvegarde temporaire
        base_image.save(temp_path)

        client = Client("unity/IP-Adapter-Instruct")

        result = client.predict(
            images=handle_file(temp_path),
            prompt=prompt,
            negative_prompt=negative_prompt,
            instruct_query=instruct_query,
            scale=scale,
            nfaa_negative_prompt=nfaa_negative_prompt,
            api_name="/generate_image"
        )

        # Suppression du fichier temporaire après utilisation
        os.remove(temp_path)
        # Convertir les fichiers images en base64 avant de les ajouter à "files"
        files = []
        for item in result:
            with open(item["image"], "rb") as image_file:
                encoded_string = base64.b64encode(image_file.read()).decode('utf-8')
                files.append(encoded_string)

        return jsonify({"result": result, "files": files})
